@@ -5,6 +5,7 @@ import xml.dom.minidom,os
 from xml.dom.minidom import Node
 import httplib
 import osmgpsmap
+import hildon
 import math
 import cairo
 from threading import Thread
@@ -99,7 +100,8 @@ class tangogps_friend:
         dialog.destroy()
 
     def get_menu_widgets(self, dialog):
-        bt_update = gtk.Button("update")
+        bt_update = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"update")
         bt_update.connect("clicked", self.on_bt_update, dialog)
         return bt_update
 
