@@ -63,6 +63,15 @@ gtk.gdk.threads_init()
 name = "yosmapa"
 version = "0.19"
 """
+0.19-5
+    move from gtk.Button to hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,
+    plugin[google_routesearch] fix after clearing route plugin don't work more in back ground
+        in portrait mode info fix width
+    fix some bugs with cross hair on / off search result / clean
+    add cashing plugins function for do_draw and on_button less stdout
+    threaded plugins different call back on "DONE searching"
+        solve floating point exception :)
 0.19-4
     plugin[google_routesearch] trip predictions for non speak mode
         clean up widget
@@ -310,6 +319,8 @@ class SearchDialog( hildon.Dialog):
         gtk.Dialog.__init__(self)
         self.osmMapa = osmMapa
 
+        self.threaded_plugin_loop = []
+
         print "SearchDialog len:",len(self.osmMapa.show_find_results)
         if len(self.osmMapa.show_find_results) > 0:
             self.osmMapa.marker_clear_from_layer( self.osmMapa.show_find_results )
@@ -352,7 +363,8 @@ class SearchDialog( hildon.Dialog):
                 #    img = gtk.Image()
                 #    img.set_from_file(s[1])
                 #    hbox.pack_start(img,False)
-                b = gtk.Button(s[0])
+                b = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,s[0])
                 b.connect("clicked", self.on_recent_click)
                 hbox.pack_start(b, True)
                 mvbox.pack_start(hbox, False)
@@ -387,7 +399,8 @@ class SearchDialog( hildon.Dialog):
 
 
 
-        bt_c = gtk.Button("[x]")
+        bt_c = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"[x]")
         hbox.pack_start(bt_c, False)
 
         e_search = gtk.Entry()
@@ -396,7 +409,8 @@ class SearchDialog( hildon.Dialog):
         bt_c.connect("clicked", self.on_clean, e_search)
 
 
-        bt_search = gtk.Button("Find")
+        bt_search = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Find")
         bt_search.connect("clicked", self.on_search, e_search)
         hbox.pack_start(bt_search,False)
 
@@ -425,7 +439,8 @@ class SearchDialog( hildon.Dialog):
         l = gtk.Label( " " )
         hbox.pack_start(l,True)
 
-        bt = gtk.Button("Action")
+        bt = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Action")
         bt.connect("clicked", self.on_result_release, i)
         hbox.pack_start(bt, False)
 
@@ -442,6 +457,8 @@ class SearchDialog( hildon.Dialog):
         CONFIG['recent_search'] = []
         CONFIG['recent_search'] = reTmp
 
+        self.threaded_plugin_loop = []
+
         d = hildon.Dialog()
         d.set_title("Results: [%s]"%CONFIG['search'])
 
@@ -485,6 +502,29 @@ class SearchDialog( hildon.Dialog):
 
     def make_delay_iter_for_ui_thread(self, plugin):
         print "make_delay_iter_for_ui_thread ",plugin[0].get_name()
+        
+        self.threaded_plugin_loop.append( plugin[0] )
+        
+        if len( self.threaded_plugin_loop ) == 1:
+            self.make_threaded_plugin_loop_run()
+            
+    def make_threaded_plugin_loop_run(self):
+        
+        
+        working = 0
+        for p in self.threaded_plugin_loop:
+            if p.ui_thread == 1:
+                working+=1
+        
+        if working == 0:
+            self.threaded_plugin_loop = []
+            self.osmMapa.recalculate_center_and_zoom()
+        
+        
+        if len( self.threaded_plugin_loop ) > 0:
+            print "make_threaded_plugin_loop_run loop",len( self.threaded_plugin_loop )
+            gobject.timeout_add( 1000, self.make_threaded_plugin_loop_run )        
+     
 
     def on_result_release(self, w, item):
         print "item release:",item
@@ -722,7 +762,8 @@ Autor: Bartlomiej Ceglik <yoyoek[noSpam]wp.pl>""")
             bt_rotate.connect("clicked", self.on_bt_rotate_click)
             hbox.pack_start(bt_rotate, pack)
 
-        bt_full = gtk.Button("(un)fullscreen")
+        bt_full = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"(un)fullscreen")
         bt_full.connect("clicked", self.on_bt_full, self)
         hbox.pack_start( bt_full, pack)
 
@@ -730,11 +771,13 @@ Autor: Bartlomiej Ceglik <yoyoek[noSpam]wp.pl>""")
 
 
         hbox = gtk.HBox()
-        bt_donate = gtk.Button("Donate")
+        bt_donate = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Donate")
         bt_donate.connect("clicked", self.on_bt_donate)
         hbox.pack_start(bt_donate, False)
 
-        bt_about = gtk.Button("About")
+        bt_about = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"About")
         bt_about.connect("clicked",self.on_bt_about)
         hbox.pack_start(bt_about, False)
 
@@ -810,6 +853,10 @@ Autor: Bartlomiej Ceglik <yoyoek[noSpam]wp.pl>""")
 
                     break
         print "plugins killIt:",deactive_list
+        
+        self.osmMapa.do_draw_plugins = []
+        self.osmMapa.do_button_release_plugins = []
+                
         for a in deactive_list:
             for plugin in self.osmMapa.plugins_list:
                 pn = plugin[1]
@@ -865,7 +912,7 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
             cr.paint()
 
             if gpsPresent:
-                if CONFIG['gpslock'] == 1:
+                if self.osmMapa.get_gpslock() == 1:
                     cr.set_source_surface( self.pb_gps_on, x,80 )
                 else:
                     cr.set_source_surface( self.pb_gps, x,80 )
@@ -941,12 +988,10 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
                 self.osmMapa.zoom_in_clicked(None)
             elif gdkeventbutton.y>80 and gdkeventbutton.y<140:
                 print "bt gps"
-                if CONFIG['gpslock']:
-                    CONFIG['gpslock'] = 0
-                    self.osmMapa.osd.props.show_crosshair = True
+                if self.osmMapa.get_gpslock():
+                    self.osmMapa.set_gpslock( 0 )
                 else:
-                    CONFIG['gpslock'] = 1
-                    self.osmMapa.osd.props.show_crosshair = False
+                    self.osmMapa.set_gpslock( 1 )
                     try:
                         if gpsPresent:
                             self.osmMapa.osm.set_center( gps.lat, gps.lon )
@@ -1025,7 +1070,7 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
                     mi = gtk.MenuItem("___________Center to")
                     mi.connect("activate",self.on_set_center,c[4],c[5])
                     m.append(mi)
-
+                    
                     if CONFIG['POI']:
                         mi = gtk.MenuItem("___________Add as POI")
                         mi.connect("activate",self.on_add_as_poi,c[4],c[5])
@@ -1082,7 +1127,7 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
 
 
     def on_set_center(self, w,lat, lon):
-        self.osmMapa.osm.set_center( lat,lon)
+        self.osmMapa.osm.set_center_and_zoom( lat,lon, 16)
 gobject.type_register(YosmapaOSD)
 
 
@@ -1099,7 +1144,7 @@ class UI(gtk.Window):
         f.close()
         if int(content) <> 0:
             CONFIG['work_work_work'] = 1
-            if CONFIG['gpslock']:
+            if self.get_gpslock():
                 self.req.req_tklock_mode_change('unlocked')
         else:
             CONFIG['work_work_work'] = 0
@@ -1155,6 +1200,10 @@ class UI(gtk.Window):
         self.ben_iter = 100
         self.show_find_results = []
         self.find_plugins = []
+        
+        self.do_draw_plugins = []
+        self.do_button_release_plugins = []
+        
 
         CONFIG['work_work_work'] = 1
 
@@ -1239,8 +1288,9 @@ class UI(gtk.Window):
     """
 
     def recalculate_center_and_zoom(self):
+        print "recalculate_center_and_zoom"
         if len(self.show_find_results)>0:
-            CONFIG['gpslock'] = 0
+            self.set_gpslock(0)
             if len(self.show_find_results ) == 1:
                 p = self.show_find_results[0]
                 self.osm.set_center_and_zoom(p[0],p[1], 17 )
@@ -1287,7 +1337,7 @@ class UI(gtk.Window):
 
                 latc, lonc = [(t_lt+b_lt)/2,(t_ln+b_ln)/2]
                 self.osm.set_center_and_zoom(latc,lonc,zoom )
-
+        print "recalculate_center_and_zoom ---- Done"
 
     def marker_draw(self,cr):
 
@@ -1530,6 +1580,17 @@ class UI(gtk.Window):
         return False
 
 
+    def set_gpslock(self, state ):
+        if state:
+            CONFIG['gpslock'] = 1
+            self.osm.set_zoom( 16 )
+            self.osd.props.show_crosshair = False
+        else:
+            CONFIG['gpslock'] = 0
+            self.osd.props.show_crosshair = True
+    def get_gpslock(self):
+        return CONFIG['gpslock']
+
     def load_map_clicked(self, button=None):
 
         try:
@@ -1549,7 +1610,7 @@ class UI(gtk.Window):
                         repo_uri=CONFIG['engine_name']
                         )
 
-            self.osd = osmgpsmap.GpsMapOsd(show_crosshair=(not CONFIG['gpslock'] ))
+            self.osd = osmgpsmap.GpsMapOsd(show_crosshair=(not self.get_gpslock() ))
             self.osm.layer_add(
                     self.osd
                     )
@@ -1614,10 +1675,24 @@ class UI(gtk.Window):
                         osmgpsmap.INVALID)
                 self.my_gps_track.append( [ math.degrees(rlat), math.degrees(rlon) ] )
 
-            for plugin in self.plugins_list:
+
+            #self.osmMapa.do_draw_plugins = []
+        #self.osmMapa.do_button_release_plugins = []
+
+            if len( self.do_button_release_plugins ) == 0:
+                make_from = self.plugins_list
+                add = 1
+            else:
+                make_from = self.do_button_release_plugins
+                add = 0
+
+
+            for plugin in make_from:
                 if CONFIG[plugin[1]]:
                     try:
                         plugin[0].do_button_release(osm,event)
+                        if add:
+                            self.do_button_release_plugins.append(plugin)
                     except Exception, e:
                         print "UI map_release ERROR:", e
 
@@ -1687,7 +1762,7 @@ class GpsManager(Thread):
 
                 if CONFIG['work_work_work']:
                     self.osmMapa.osm.gps_add( self.lat, self.lon, self.heading)
-                    if CONFIG['gpslock'] == 1:
+                    if self.osmMapa.get_gpslock() == 1:
                        self.osmMapa.osm.set_center( self.lat, self.lon )
                        CONFIG['lat'], CONFIG['lon'] = self.lat, self.lon
                 # data.stop() commented out to allow continuous loop for a reliable fix - press ctrl c to break the loop, or program your own way of exiting)
@@ -1763,8 +1838,14 @@ class PluginsLayer(gobject.GObject, osmgpsmap.GpsMapLayer):
 
             self.osmMapa.marker_draw(gdkdrawable.cairo_create())
 
+            if len( self.osmMapa.do_draw_plugins ) == 0:
+                make_from = self.plugins
+                add = 1
+            else:
+                make_from = self.osmMapa.do_draw_plugins
+                add = 0
 
-            for plugin in self.plugins:
+            for plugin in make_from:
                 if CONFIG[plugin[1]]:
                     try:
                         if timing_plugins:
@@ -1772,8 +1853,12 @@ class PluginsLayer(gobject.GObject, osmgpsmap.GpsMapLayer):
                         plugin[0].do_draw(gpsmap, gdkdrawable)
                         if timing_plugins:
                             print "plugin ", plugin[1]," in ",(time.time()-tp)
+                        if add:
+                            self.osmMapa.do_draw_plugins.append(plugin)
                     except Exception, e:
                         print "PluginsLayer do_draw ERROR (",plugin[1],"):", e
+                        
+            
             if timing_plugins:
                 print "PluginsLayers in",(time.time()-t)
             self.make_draw = 0
